@@ -5,11 +5,12 @@ import tempfile
 from pathlib import Path
 
 import click
-from prompt_toolkit.shortcuts import confirm
+from rich.console import Console
 
 from taskrepo.core.repository import RepositoryManager
 from taskrepo.tui import prompts
 from taskrepo.tui.task_tui import TaskTUI
+from taskrepo.utils.conflict_detection import display_conflict_warning, scan_all_repositories
 from taskrepo.utils.id_mapping import save_id_cache
 from taskrepo.utils.sorting import sort_tasks
 
@@ -34,6 +35,9 @@ def tui(ctx, repo):
         d - Mark as done
         p - Toggle in-progress/pending
         c - Mark as cancelled
+        H - Set priority to High
+        M - Set priority to Medium
+        L - Set priority to Low
         a - Archive task
         x - Delete task
 
@@ -53,6 +57,15 @@ def tui(ctx, repo):
         click.echo("Create one with: tsk create-repo")
         ctx.exit(1)
 
+    # Check for unresolved merge conflicts before starting TUI
+    conflicts = scan_all_repositories(Path(config.parent_dir).expanduser())
+    if conflicts:
+        console = Console()
+        display_conflict_warning(conflicts, console)
+        if not click.confirm("Continue anyway?", default=False):
+            click.echo("Aborted. Please resolve conflicts first with: tsk sync")
+            ctx.exit(1)
+
     # If repo specified, find its index and start there
     start_repo_idx = -1  # Default to "All" tab
     if repo:
@@ -65,7 +78,7 @@ def tui(ctx, repo):
     # Update ID cache with all tasks before starting TUI
     manager = RepositoryManager(config.parent_dir)
     all_tasks = manager.list_all_tasks(include_archived=False)
-    sorted_tasks = sort_tasks(all_tasks, config)
+    sorted_tasks = sort_tasks(all_tasks, config, all_tasks=all_tasks)
     save_id_cache(sorted_tasks)
 
     # Create and run TUI in a loop
@@ -103,6 +116,16 @@ def tui(ctx, repo):
             _handle_archive_task(task_tui, config)
         elif result == "move":
             _handle_move_task(task_tui, config)
+        elif result == "subtask":
+            _handle_subtask(task_tui, config)
+        elif result == "extend":
+            _handle_extend(task_tui, config)
+        elif result == "priority-high":
+            _handle_priority_change(task_tui, "H")
+        elif result == "priority-medium":
+            _handle_priority_change(task_tui, "M")
+        elif result == "priority-low":
+            _handle_priority_change(task_tui, "L")
         elif result == "info":
             _handle_info_task(task_tui)
         elif result == "sync":
@@ -110,7 +133,7 @@ def tui(ctx, repo):
 
         # Update ID cache after task operations
         all_tasks = manager.list_all_tasks(include_archived=False)
-        sorted_tasks = sort_tasks(all_tasks, config)
+        sorted_tasks = sort_tasks(all_tasks, config, all_tasks=all_tasks)
         save_id_cache(sorted_tasks)
 
         # Recreate TUI to refresh, restoring view state
@@ -138,8 +161,6 @@ def _handle_new_task(task_tui: TaskTUI, config):
         repo = prompts.prompt_repository(task_tui.repositories)
         if not repo:
             click.echo("Cancelled.")
-            click.echo("Press Enter to continue...")
-            input()
             return
 
     # Use existing interactive prompts
@@ -183,23 +204,16 @@ def _handle_new_task(task_tui: TaskTUI, config):
 
     repo.save_task(task)
     click.secho(f"\n✓ Created task: {task.title}", fg="green")
-    click.echo("\nPress Enter to continue...")
-    input()
 
 
 def _handle_edit_task(task_tui: TaskTUI, config):
     """Handle editing selected task(s)."""
     selected_tasks = task_tui._get_selected_tasks()
     if not selected_tasks:
-        click.echo("\nNo task selected.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     if len(selected_tasks) > 1:
         click.secho("\n⚠ Cannot edit multiple tasks at once. Select only one task.", fg="yellow")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     task = selected_tasks[0]
@@ -211,8 +225,6 @@ def _handle_edit_task(task_tui: TaskTUI, config):
         repo = next((r for r in task_tui.repositories if r.name == task.repo), None)
         if not repo:
             click.secho(f"\n✗ Could not find repository for task: {task.repo}", fg="red")
-            click.echo("Press Enter to continue...")
-            input()
             return
 
     # Open task in editor
@@ -253,9 +265,6 @@ def _handle_edit_task(task_tui: TaskTUI, config):
         # Clean up temp file
         Path(temp_path).unlink(missing_ok=True)
 
-    click.echo("Press Enter to continue...")
-    input()
-
 
 def _handle_in_progress_toggle(task_tui: TaskTUI):
     """Handle toggling between in-progress and pending status."""
@@ -314,13 +323,36 @@ def _handle_status_change(task_tui: TaskTUI, new_status: str):
     task_tui.multi_selected.clear()
 
 
+def _handle_priority_change(task_tui: TaskTUI, new_priority: str):
+    """Handle changing priority of selected task(s)."""
+    selected_tasks = task_tui._get_selected_tasks()
+    if not selected_tasks:
+        # Silently return if no task selected
+        return
+
+    from datetime import datetime
+
+    # Update each task in its respective repository
+    for task in selected_tasks:
+        # Find the repository for this task by name (works in all view modes)
+        repo = next((r for r in task_tui.repositories if r.name == task.repo), None)
+
+        if not repo:
+            # Skip this task if repo not found
+            continue
+
+        task.priority = new_priority
+        task.modified = datetime.now()
+        repo.save_task(task)
+
+    # Clear multi-selection (no message, immediate return to TUI)
+    task_tui.multi_selected.clear()
+
+
 def _handle_delete_task(task_tui: TaskTUI):
     """Handle deleting selected task(s)."""
     selected_tasks = task_tui._get_selected_tasks()
     if not selected_tasks:
-        click.echo("\nNo task selected.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     # Confirm deletion
@@ -330,10 +362,8 @@ def _handle_delete_task(task_tui: TaskTUI):
         message = f"Delete {len(selected_tasks)} tasks?"
 
     click.echo(f"\n{message}")
-    if not confirm("Confirm deletion?"):
+    if not prompts.confirm_single_key("Confirm deletion?"):
         click.echo("Cancelled.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     # Delete each task from its respective repository
@@ -352,9 +382,6 @@ def _handle_delete_task(task_tui: TaskTUI):
     else:
         click.secho(f"\n✓ Deleted {len(selected_tasks)} tasks", fg="green")
 
-    click.echo("Press Enter to continue...")
-    input()
-
     # Clear multi-selection
     task_tui.multi_selected.clear()
 
@@ -363,9 +390,6 @@ def _handle_archive_task(task_tui: TaskTUI, config):
     """Handle archiving selected task(s)."""
     selected_tasks = task_tui._get_selected_tasks()
     if not selected_tasks:
-        click.echo("\nNo task selected.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     # Confirm archiving
@@ -375,10 +399,8 @@ def _handle_archive_task(task_tui: TaskTUI, config):
         message = f"Archive {len(selected_tasks)} tasks?"
 
     click.echo(f"\n{message}")
-    if not confirm("Confirm archiving?"):
+    if not prompts.confirm_single_key("Confirm archiving?"):
         click.echo("Cancelled.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     # Archive each task from its respective repository
@@ -415,9 +437,6 @@ def _handle_move_task(task_tui: TaskTUI, config):
 
     selected_tasks = task_tui._get_selected_tasks()
     if not selected_tasks:
-        click.echo("\nNo task selected.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     # Prompt for target repository
@@ -428,8 +447,6 @@ def _handle_move_task(task_tui: TaskTUI, config):
     target_repo = prompts.prompt_repository(task_tui.repositories)
     if not target_repo:
         click.echo("Cancelled.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     # Confirm move
@@ -439,10 +456,8 @@ def _handle_move_task(task_tui: TaskTUI, config):
         message = f"Move {len(selected_tasks)} tasks to repository '{target_repo.name}'?"
 
     click.echo(f"\n{message}")
-    if not confirm("Confirm move?"):
+    if not prompts.confirm_single_key("Confirm move?"):
         click.echo("Cancelled.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     # Initialize manager for subtask checking
@@ -469,7 +484,7 @@ def _handle_move_task(task_tui: TaskTUI, config):
 
             if subtasks_with_repos:
                 click.echo(f"\nTask '{task.title}' has {len(subtasks_with_repos)} subtask(s).")
-                if confirm("Move subtasks as well?"):
+                if prompts.confirm_single_key("Move subtasks as well?"):
                     move_subtasks = True
 
             # Check for dependencies
@@ -517,9 +532,6 @@ def _handle_move_task(task_tui: TaskTUI, config):
         else:
             click.secho(f"\n✓ Moved {moved_count} of {len(selected_tasks)} tasks to '{target_repo.name}'", fg="green")
 
-    click.echo("Press Enter to continue...")
-    input()
-
     # Clear multi-selection
     task_tui.multi_selected.clear()
 
@@ -530,19 +542,169 @@ def _is_task_archived(repository, task_id: str) -> bool:
     return archive_path.exists()
 
 
+def _handle_subtask(task_tui: TaskTUI, config):
+    """Handle creating a subtask under the selected task."""
+    selected_tasks = task_tui._get_selected_tasks()
+    if not selected_tasks:
+        return
+
+    if len(selected_tasks) > 1:
+        click.secho("\n⚠ Cannot create subtask under multiple tasks. Select only one task.", fg="yellow")
+        return
+
+    parent_task = selected_tasks[0]
+
+    # Find the repository for this task
+    repo = next((r for r in task_tui.repositories if r.name == parent_task.repo), None)
+    if not repo:
+        click.secho(f"\n✗ Could not find repository for task: {parent_task.repo}", fg="red")
+        return
+
+    # Use existing interactive prompts
+    click.echo("\n" + "=" * 50)
+    click.echo(f"Create Subtask under: {parent_task.title}")
+    click.echo("=" * 50)
+
+    title = prompts.prompt_title()
+    if not title:
+        click.echo("Cancelled.")
+        return
+
+    # Get existing values for autocomplete
+    existing_projects = repo.get_projects()
+    existing_assignees = repo.get_assignees()
+    existing_tags = repo.get_tags()
+
+    # Prompt for other task details
+    project = prompts.prompt_project(existing_projects, default=parent_task.project)
+    priority = prompts.prompt_priority(default=config.default_priority or "M")
+    assignees = prompts.prompt_assignees(existing_assignees, default=parent_task.assignees)
+    tags = prompts.prompt_tags(existing_tags, default=parent_task.tags)
+    links = prompts.prompt_links()
+    due_date = prompts.prompt_due_date()
+    description = prompts.prompt_description()
+
+    # Create the task
+    from datetime import datetime
+
+    from taskrepo.core.task import Task
+
+    task = Task(
+        id=repo.next_task_id(),
+        title=title,
+        status=config.default_status or "pending",
+        project=project,
+        priority=priority,
+        assignees=assignees,
+        tags=tags,
+        links=links,
+        parent=parent_task.id,  # Set parent to create subtask relationship
+        due=due_date,
+        description=description,
+        created=datetime.now(),
+        modified=datetime.now(),
+        repo=repo.name,
+    )
+
+    repo.save_task(task)
+    click.secho(f"\n✓ Created subtask: {task.title}", fg="green")
+
+    # Clear multi-selection
+    task_tui.multi_selected.clear()
+
+
+def _handle_extend(task_tui: TaskTUI, config):
+    """Handle extending task due date(s)."""
+    selected_tasks = task_tui._get_selected_tasks()
+    if not selected_tasks:
+        return
+
+    click.echo("\n" + "=" * 50)
+    click.echo(f"Extend Task Due Date{'s' if len(selected_tasks) > 1 else ''}")
+    click.echo("=" * 50)
+
+    # Show selected tasks
+    if len(selected_tasks) == 1:
+        task = selected_tasks[0]
+        click.echo(f"\nTask: {task.title}")
+        if task.due:
+            click.echo(f"Current due date: {task.due.strftime('%Y-%m-%d')}")
+        else:
+            click.echo("Current due date: None")
+    else:
+        click.echo(f"\n{len(selected_tasks)} tasks selected")
+
+    # Prompt for date or duration
+    click.echo("\nEnter date or duration:")
+    click.echo("  Durations: 1w, 2d, 3m, 1y (extends from current due date)")
+    click.echo("  Keywords: today, tomorrow, next week, next month, next year")
+    click.echo("  Weekdays: next monday, this friday, monday")
+    click.echo("  ISO dates: 2025-10-30")
+    click.echo("  Natural dates: 'Oct 30', 'October 30 2025'")
+
+    date_input = click.prompt("\nDate or duration", type=str, default="")
+    if not date_input:
+        click.echo("Cancelled.")
+        return
+
+    # Parse date or duration
+    from taskrepo.utils.date_parser import parse_date_or_duration
+
+    try:
+        parsed_value, is_absolute_date = parse_date_or_duration(date_input)
+    except ValueError as e:
+        click.secho(f"\n✗ Error: {e}", fg="red")
+        return
+
+    # Apply to all selected tasks
+    from datetime import datetime
+
+    extended_count = 0
+    for task in selected_tasks:
+        # Find the repository for this task
+        repo = next((r for r in task_tui.repositories if r.name == task.repo), None)
+        if not repo:
+            continue
+
+        # Calculate new due date
+        if is_absolute_date:
+            # Set to specific date
+            new_due = parsed_value
+        else:
+            # Extend by duration
+            if task.due:
+                new_due = task.due + parsed_value
+            else:
+                new_due = datetime.now() + parsed_value
+
+        # Update task
+        task.due = new_due
+        task.modified = datetime.now()
+        repo.save_task(task)
+        extended_count += 1
+
+    # Show result
+    if extended_count > 0:
+        action_verb = "Updated" if is_absolute_date else "Extended"
+        if len(selected_tasks) == 1:
+            click.secho(f"\n✓ {action_verb} task: {selected_tasks[0].title}", fg="green")
+        else:
+            click.secho(f"\n✓ {action_verb} {extended_count} task{'s' if extended_count != 1 else ''}", fg="green")
+    else:
+        click.secho("\n✗ Failed to update any tasks", fg="red")
+
+    # Clear multi-selection
+    task_tui.multi_selected.clear()
+
+
 def _handle_info_task(task_tui: TaskTUI):
     """Handle viewing task info."""
     selected_tasks = task_tui._get_selected_tasks()
     if not selected_tasks:
-        click.echo("\nNo task selected.")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     if len(selected_tasks) > 1:
         click.secho("\n⚠ Select only one task to view details.", fg="yellow")
-        click.echo("Press Enter to continue...")
-        input()
         return
 
     task = selected_tasks[0]
@@ -609,8 +771,6 @@ def _handle_sort_change(task_tui: TaskTUI, config):
         choice = input("\nSort by: ").strip()
         if not choice:
             click.echo("Cancelled.")
-            click.echo("Press Enter to continue...")
-            input()
             return
 
         # Parse choice
@@ -654,9 +814,6 @@ def _handle_sort_change(task_tui: TaskTUI, config):
     except (KeyboardInterrupt, EOFError):
         click.echo("\nCancelled.")
 
-    click.echo("Press Enter to continue...")
-    input()
-
 
 def _handle_sync(task_tui: TaskTUI, config):
     """Handle syncing with git."""
@@ -679,8 +836,6 @@ def _handle_sync(task_tui: TaskTUI, config):
             repo = task_tui._get_current_repo()
             if not repo:
                 click.echo("\nNo repository selected.")
-                click.echo("Press Enter to continue...")
-                input()
                 return
             repositories_to_sync = [repo]
             click.echo("\n" + "=" * 50)
@@ -802,11 +957,38 @@ def _handle_sync(task_tui: TaskTUI, config):
                         click.secho(f"  ✓ Resolved {resolved_count} conflict(s)", fg="green")
 
                 # Pull from remote
-                click.echo("  • Pulling from remote...")
-                origin = git_repo.remotes.origin
-                # Use --rebase=false to handle divergent branches
-                git_repo.git.pull("--rebase=false", "origin", git_repo.active_branch.name)
-                click.secho("  ✓ Pulled from remote", fg="green")
+                pull_succeeded = True
+                try:
+                    click.echo("  • Pulling from remote...")
+                    origin = git_repo.remotes.origin
+                    # Use --rebase=false to handle divergent branches
+                    git_repo.git.pull("--rebase=false", "origin", git_repo.active_branch.name)
+                    click.secho("  ✓ Pulled from remote", fg="green")
+                except GitCommandError as e:
+                    if "would be overwritten" in str(e) or "conflict" in str(e).lower():
+                        pull_succeeded = False
+                        click.secho("  ⚠ Pull created conflicts", fg="yellow")
+                    else:
+                        raise
+
+                # Check for conflict markers after pull
+                from rich.console import Console
+
+                from taskrepo.cli.commands.sync import _has_conflict_markers, _resolve_conflict_markers
+
+                if not pull_succeeded or _has_conflict_markers(repository.path):
+                    click.echo("  • Resolving conflict markers...")
+                    console = Console()
+                    resolved_files = _resolve_conflict_markers(repository, console)
+
+                    if resolved_files:
+                        click.secho(f"  ✓ Auto-resolved {len(resolved_files)} conflicted file(s)", fg="green")
+
+                        # Commit the resolutions
+                        for file_path in resolved_files:
+                            git_repo.git.add(str(file_path))
+                        git_repo.index.commit(f"Auto-resolve: Fixed {len(resolved_files)} conflict marker(s)")
+                        click.secho("  ✓ Committed conflict resolutions", fg="green")
 
                 # Push to remote
                 click.echo("  • Pushing to remote...")
@@ -823,5 +1005,3 @@ def _handle_sync(task_tui: TaskTUI, config):
     click.echo("\n" + "=" * 50)
     click.secho("Sync complete!", fg="green")
     click.echo("=" * 50)
-    click.echo("\nPress Enter to continue...")
-    input()
