@@ -218,11 +218,12 @@ def prompt_title() -> Optional[str]:
         return None
 
 
-def prompt_project(existing_projects: list[str]) -> Optional[str]:
+def prompt_project(existing_projects: list[str], default: Optional[str] = None) -> Optional[str]:
     """Prompt user for project name with autocomplete.
 
     Args:
         existing_projects: List of existing project names
+        default: Default project name to pre-fill
 
     Returns:
         Project name or None
@@ -234,28 +235,34 @@ def prompt_project(existing_projects: list[str]) -> Optional[str]:
             "Project (optional): ",
             completer=completer,
             complete_while_typing=True,
+            default=default or "",
         )
         return project.strip() or None
     except (KeyboardInterrupt, EOFError):
         return None
 
 
-def prompt_assignees(existing_assignees: list[str]) -> list[str]:
+def prompt_assignees(existing_assignees: list[str], default: Optional[list[str]] = None) -> list[str]:
     """Prompt user for assignees (comma-separated GitHub handles).
 
     Args:
         existing_assignees: List of existing assignee handles
+        default: Default list of assignees to pre-fill
 
     Returns:
         List of assignee handles
     """
     completer = CommaDelimitedCompleter(existing_assignees) if existing_assignees else None
 
+    # Convert default list to comma-separated string
+    default_str = ", ".join(default) if default else ""
+
     try:
         assignees_str = prompt(
             "Assignees (comma-separated, e.g., @user1,@user2): ",
             completer=completer,
             complete_while_typing=True,
+            default=default_str,
         )
 
         if not assignees_str.strip():
@@ -328,22 +335,27 @@ def prompt_priority(default: str = "M") -> str:
         return default
 
 
-def prompt_tags(existing_tags: list[str]) -> list[str]:
+def prompt_tags(existing_tags: list[str], default: Optional[list[str]] = None) -> list[str]:
     """Prompt user for tags (comma-separated).
 
     Args:
         existing_tags: List of existing tags
+        default: Default list of tags to pre-fill
 
     Returns:
         List of tags
     """
     completer = CommaDelimitedCompleter(existing_tags) if existing_tags else None
 
+    # Convert default list to comma-separated string
+    default_str = ", ".join(default) if default else ""
+
     try:
         tags_str = prompt(
             "Tags (comma-separated): ",
             completer=completer,
             complete_while_typing=True,
+            default=default_str,
         )
 
         if not tags_str.strip():
@@ -749,3 +761,91 @@ def prompt_parent_task(existing_tasks: list) -> Optional[str]:
 
     except (KeyboardInterrupt, EOFError):
         return None
+
+
+def confirm_single_key(message: str) -> bool:
+    """Prompt for yes/no confirmation with single-key input (no Enter required).
+
+    Args:
+        message: The confirmation message to display
+
+    Returns:
+        True if user confirmed (pressed 'y'), False otherwise
+    """
+    from prompt_toolkit.application import Application
+    from prompt_toolkit.formatted_text import HTML
+    from prompt_toolkit.key_binding import KeyBindings
+    from prompt_toolkit.layout import Layout, Window
+    from prompt_toolkit.layout.controls import FormattedTextControl
+
+    result = [False]  # Use list to allow modification in nested function
+
+    kb = KeyBindings()
+
+    @kb.add("y")
+    @kb.add("Y")
+    def yes(event):
+        result[0] = True
+        event.app.exit()
+
+    @kb.add("n")
+    @kb.add("N")
+    @kb.add("escape")
+    def no(event):
+        result[0] = False
+        event.app.exit()
+
+    # Create a simple layout with the message
+    layout = Layout(Window(content=FormattedTextControl(HTML(f"<b>{message}</b> (y/n): "))))
+
+    # Create and run application
+    app: Application[None] = Application(
+        layout=layout,
+        key_bindings=kb,
+        full_screen=False,
+    )
+
+    app.run()
+    return result[0]
+
+
+def prompt_yes_no(message: str, default: str = "y") -> bool:
+    """Reusable yes/no confirmation prompt.
+
+    This function centralizes the common yes/no prompt pattern used throughout
+    the CLI commands, providing consistent validation and user experience.
+
+    Args:
+        message: The question to ask the user (should not include "(y/n)")
+        default: Default value - "y" for yes (default), "n" for no
+
+    Returns:
+        True if user answered yes, False if user answered no
+
+    Example:
+        >>> if prompt_yes_no("Delete this task?"):
+        ...     delete_task()
+        >>> if prompt_yes_no("Archive subtasks?", default="y"):
+        ...     archive_subtasks()
+    """
+    # Create validator for y/n input
+    yn_validator = Validator.from_callable(
+        lambda text: text.lower() in ["y", "n", "yes", "no"],
+        error_message="Please enter 'y' or 'n'",
+        move_cursor_to_end=True,
+    )
+
+    # Add (Y/n) or (y/N) suffix based on default
+    if default.lower() == "y":
+        prompt_suffix = " (Y/n) "
+    else:
+        prompt_suffix = " (y/N) "
+
+    # Get user response
+    response = prompt(
+        message + prompt_suffix,
+        default=default,
+        validator=yn_validator,
+    ).lower()
+
+    return response in ["y", "yes"]
