@@ -1,6 +1,7 @@
 """Full-screen TUI for TaskRepo using prompt_toolkit."""
 
 import asyncio
+import html
 import os
 from pathlib import Path
 from typing import Optional
@@ -61,14 +62,24 @@ class TaskTUI:
         self.filter_active = False
         self.show_detail_panel = True  # Always show detail panel
 
-        # Viewport scrolling state
-        self.viewport_top = 0  # First task visible in viewport
-        self.viewport_size = self._calculate_viewport_size()  # Dynamic based on terminal size
-        self.scroll_trigger = min(5, max(2, self.viewport_size // 3))  # Start scrolling at 1/3 of viewport
-
         # Auto-reload state
         self.last_mtime = self._get_repositories_mtime()
         self.auto_reload_task: Optional[asyncio.Task] = None
+        self.last_reload_time: Optional[float] = None  # timestamp of last reload
+
+        # Background sync state (must be initialized before _calculate_viewport_size)
+        self.sync_status = "idle"  # "idle", "syncing", "success", "error"
+        self.last_sync_time: Optional[float] = None  # timestamp of last sync
+        self.next_sync_time: Optional[float] = None  # timestamp of next scheduled sync
+        self.conflicted_repos: set[str] = set()  # repos needing manual resolution
+        self.background_sync_task: Optional[asyncio.Task] = None
+        self.sync_message: Optional[str] = None  # temporary status bar message
+
+        # Viewport scrolling state (depends on sync state for height calculation)
+        self.viewport_top = 0  # First task visible in viewport
+        self.viewport_size = self._calculate_viewport_size()  # Dynamic based on terminal size
+        self.scroll_trigger = min(5, max(2, self.viewport_size // 3))  # Start scrolling at 1/3 of viewport
+        self.sync_message_time: Optional[float] = None  # when message was set
 
         # Create filter input widget
         self.filter_input = TextArea(
@@ -162,10 +173,15 @@ class TaskTUI:
 
     async def _auto_reload_loop(self):
         """Background task that periodically checks for file changes and reloads."""
+        import time
+
         while True:
             await asyncio.sleep(2)  # Check every 2 seconds
 
             if self._check_for_changes():
+                # Track reload time
+                self.last_reload_time = time.time()
+
                 # Reload repositories from disk
                 manager = RepositoryManager(self.config.parent_dir)
                 self.repositories = manager.discover_repositories()
@@ -175,7 +191,7 @@ class TaskTUI:
 
                 # Update ID cache with all current tasks
                 all_tasks = manager.list_all_tasks(include_archived=False)
-                sorted_tasks = sort_tasks(all_tasks, self.config)
+                sorted_tasks = sort_tasks(all_tasks, self.config, all_tasks=all_tasks)
                 save_id_cache(sorted_tasks)
 
                 # Clear multi-selection since task IDs may have changed
@@ -189,6 +205,121 @@ class TaskTUI:
                 # Invalidate the display to trigger a redraw
                 self.app.invalidate()
 
+    async def _background_sync_loop(self):
+        """Background task that periodically syncs repositories."""
+        import time
+
+        while True:
+            await asyncio.sleep(self.config.auto_sync_interval)
+
+            # Skip if user is busy (editing or in a modal)
+            if self._should_skip_sync():
+                continue
+
+            # Start sync
+            self.sync_status = "syncing"
+            self.app.invalidate()
+
+            # Sync each repository
+            success_count = 0
+            error_count = 0
+            conflict_count = 0
+
+            for repo in self.repositories:
+                # Skip repos already marked as conflicted
+                if repo.name in self.conflicted_repos:
+                    continue
+
+                success, error_msg, has_conflicts = await self._sync_repository_async(repo)
+
+                if success:
+                    success_count += 1
+                elif has_conflicts:
+                    conflict_count += 1
+                    self.conflicted_repos.add(repo.name)
+                else:
+                    error_count += 1
+
+            # Update sync status and message
+            self.last_sync_time = time.time()
+            self.next_sync_time = time.time() + self.config.auto_sync_interval
+
+            if error_count > 0 or conflict_count > 0:
+                self.sync_status = "error"
+                if conflict_count > 0:
+                    self._set_sync_message(f"⚠ {conflict_count} repo(s) need manual sync")
+                else:
+                    self._set_sync_message(f"⚠ Sync failed for {error_count} repo(s)")
+            else:
+                self.sync_status = "success"
+                if success_count > 0:
+                    self._set_sync_message(f"✓ Synced {success_count} repo(s)")
+
+            # Reload repositories after sync
+            if success_count > 0:
+                manager = RepositoryManager(self.config.parent_dir)
+                self.repositories = manager.discover_repositories()
+                self.view_items = self._build_view_items()
+
+                # Update ID cache
+                all_tasks = manager.list_all_tasks(include_archived=False)
+                sorted_tasks = sort_tasks(all_tasks, self.config, all_tasks=all_tasks)
+                save_id_cache(sorted_tasks)
+
+            self.app.invalidate()
+
+    async def _sync_repository_async(self, repository) -> tuple[bool, str, bool]:
+        """Async wrapper for repository sync.
+
+        Args:
+            repository: Repository to sync
+
+        Returns:
+            Tuple of (success, error_message, has_conflicts)
+        """
+        from taskrepo.utils.async_sync import sync_repository_background
+
+        # Run sync in executor to avoid blocking
+        loop = asyncio.get_event_loop()
+        return await loop.run_in_executor(None, sync_repository_background, repository, self.config.auto_sync_strategy)
+
+    def _should_skip_sync(self) -> bool:
+        """Check if background sync should be skipped.
+
+        Returns:
+            True if sync should be skipped
+        """
+        # Skip if user is editing a task or in a modal
+        # We can detect this by checking if the app is showing a dialog
+        # For now, we'll always allow sync since we invalidate after
+        return False
+
+    def _set_sync_message(self, message: str):
+        """Set a temporary status bar message.
+
+        Args:
+            message: Message to display
+        """
+        import time
+
+        self.sync_message = message
+        self.sync_message_time = time.time()
+
+    def _get_sync_indicator(self) -> str:
+        """Get sync status indicator for header.
+
+        Returns:
+            Sync status string (emoji + text)
+        """
+        if self.sync_status == "syncing":
+            return "🔄"
+        elif self.sync_status == "success":
+            return "✓"
+        elif self.sync_status == "error":
+            return "⚠"
+        else:
+            return ""
+
     def _get_terminal_size(self):
         """Get current terminal size."""
         try:
@@ -209,13 +340,14 @@ class TaskTUI:
         # - Detail panel content: dynamic (see _calculate_detail_panel_height)
         # - Detail panel Frame borders: 2 lines (top + bottom)
         # - Filter input: 1 line (when visible)
-        # - Status bar: 1 line
+        # - Status bar: dynamic (see _calculate_status_bar_height)
         # - Scroll indicators: 2 lines (max)
 
         detail_panel_height = self._calculate_detail_panel_height()
-        fixed_lines = 1 + 2 + detail_panel_height + 2 + 1 + 1 + 2  # All fixed elements
+        status_bar_height = self._calculate_status_bar_height()
+        fixed_lines = 1 + 2 + detail_panel_height + 2 + 1 + status_bar_height + 2  # All fixed elements
         # = header + task header/sep + detail content + frame borders + filter + status + scrollers
-        # = detail_panel_height + 9
+        # = detail_panel_height + status_bar_height + 8
 
         available_lines = terminal_height - fixed_lines
 
@@ -237,6 +369,45 @@ class TaskTUI:
 
         return detail_height
 
+    def _calculate_status_bar_height(self) -> int:
+        """Calculate status bar height based on content and terminal width.
+
+        Returns 2 for wide terminals (>=120 cols) when status info is present,
+        otherwise returns 1 (or more if wrapping occurs on very narrow terminals).
+        """
+        import re
+
+        _, terminal_width = self._get_terminal_size()
+
+        # Build status info to check if we have any
+        status_info = self._build_status_info()
+
+        # Two-line layout for medium/wide terminals with status info
+        if terminal_width >= 120 and status_info:
+            return 2
+
+        # Single-line layout - check if wrapping is needed
+        # Get the actual combined content length
+        shortcuts = self._get_shortcuts_text(terminal_width)
+
+        # Strip HTML tags to get visible character count
+        def strip_html(text):
+            return re.sub(r"<[^>]+>", "", text)
+
+        if status_info:
+            # Combined: "status | shortcuts"
+            visible_status = strip_html(status_info)
+            content_length = len(visible_status) + 3 + len(shortcuts) + 2  # +3 for " | ", +2 for padding
+        else:
+            # Just shortcuts
+            content_length = len(shortcuts) + 2  # +2 for padding
+
+        # Calculate lines needed for wrapping (round up)
+        lines_needed = (content_length + terminal_width - 1) // terminal_width
+
+        # Ensure at least 1 line, max 3 lines (in case of very narrow terminal)
+        return max(1, min(3, lines_needed))
+
     def _create_style(self) -> Style:
         """Create the color scheme for the TUI."""
         return Style.from_dict(
@@ -392,7 +563,7 @@ class TaskTUI:
                     self.multi_selected.add(task_id)
 
         # Task operations (only when not filtering)
-        @kb.add("n", filter=Condition(lambda: not self.filter_active))
+        @kb.add("a", filter=Condition(lambda: not self.filter_active))
         def _(event):
             """Create a new task."""
             event.app.exit(result="new")
@@ -404,7 +575,7 @@ class TaskTUI:
 
         @kb.add("d", filter=Condition(lambda: not self.filter_active))
         def _(event):
-            """Mark task(s) as done."""
+            """Mark task(s) as completed (done)."""
             event.app.exit(result="done")
 
         @kb.add("p", filter=Condition(lambda: not self.filter_active))
@@ -417,12 +588,12 @@ class TaskTUI:
             """Mark task(s) as cancelled."""
             event.app.exit(result="cancelled")
 
-        @kb.add("x", filter=Condition(lambda: not self.filter_active))
+        @kb.add("l", filter=Condition(lambda: not self.filter_active))
         def _(event):
             """Delete task(s)."""
             event.app.exit(result="delete")
 
-        @kb.add("a", filter=Condition(lambda: not self.filter_active))
+        @kb.add("v", filter=Condition(lambda: not self.filter_active))
         def _(event):
             """Archive task(s)."""
             event.app.exit(result="archive")
@@ -432,8 +603,34 @@ class TaskTUI:
             """Move task(s) to another repository."""
             event.app.exit(result="move")
 
-        # View operations (only when not filtering)
+        @kb.add("u", filter=Condition(lambda: not self.filter_active))
+        def _(event):
+            """Create subtask under selected task."""
+            event.app.exit(result="subtask")
+
         @kb.add("t", filter=Condition(lambda: not self.filter_active))
+        def _(event):
+            """Extend task due date."""
+            event.app.exit(result="extend")
+
+        # Priority change operations (only when not filtering)
+        @kb.add("H", filter=Condition(lambda: not self.filter_active))
+        def _(event):
+            """Set task(s) priority to High."""
+            event.app.exit(result="priority-high")
+
+        @kb.add("M", filter=Condition(lambda: not self.filter_active))
+        def _(event):
+            """Set task(s) priority to Medium."""
+            event.app.exit(result="priority-medium")
+
+        @kb.add("L", filter=Condition(lambda: not self.filter_active))
+        def _(event):
+            """Set task(s) priority to Low."""
+            event.app.exit(result="priority-low")
+
+        # View operations (only when not filtering)
+        @kb.add("r", filter=Condition(lambda: not self.filter_active))
         def _(event):
             """Toggle tree view."""
             self.tree_view = not self.tree_view
@@ -502,7 +699,8 @@ class TaskTUI:
         # Status bar with keyboard shortcuts
         status_bar = Window(
             content=FormattedTextControl(self._get_status_bar_text),
-            height=Dimension.exact(1),
+            height=lambda: Dimension.exact(self._calculate_status_bar_height()),  # Dynamic height
+            wrap_lines=True,
             style="bg:ansiblack fg:ansiwhite",
         )
 
@@ -550,20 +748,119 @@ class TaskTUI:
             current_pos = self.current_view_idx + 2  # +2 because "All" is position 1
 
         total_tabs = len(self.view_items) + 1  # +1 for "All" tab
-        view_info = f"{view_label}: {view_name} ({current_pos}/{total_tabs}) [←/→ items | Tab: view type]"
+        view_info = f"{view_label}: {html.escape(view_name)} ({current_pos}/{total_tabs}) [←/→ items | Tab: view type]"
 
         if self.filter_text:
-            view_info += f" | Filter: '{self.filter_text}'"
+            view_info += f" | Filter: '{html.escape(self.filter_text)}'"
+
+        # Add sync status indicator if auto-sync is enabled
+        if self.config.auto_sync_enabled:
+            sync_indicator = self._get_sync_indicator()
+            if sync_indicator:
+                view_info += f" | {sync_indicator}"
 
         return HTML(f"<b> {view_info} </b>")
 
-    def _get_status_bar_text(self) -> FormattedText:
-        """Get the status bar text with keyboard shortcuts."""
-        shortcuts = (
-            "[n]ew [e]dit [d]one [p]rogress [c]ancelled [a]rchive [m]ove [x]del "
-            "[s]ync [/]filter [t]ree [q]uit | Multi-select: Space | Auto-reload: ON"
+    def _build_status_info(self) -> str:
+        """Build status information string with sync/reload/conflict info.
+
+        Returns:
+            HTML-formatted status string with priority information
+        """
+        from taskrepo.utils.time_format import format_interval, format_time_ago
+
+        parts = []
+
+        # Priority 1: Conflict warnings (highest priority)
+        if self.conflicted_repos:
+            count = len(self.conflicted_repos)
+            parts.append(f"<yellow>⚠ {count} repo{'s' if count > 1 else ''} need manual sync</yellow>")
+
+        # Priority 2: Active sync status
+        if self.sync_status == "syncing":
+            parts.append("<cyan>🔄 Syncing...</cyan>")
+        elif self.sync_status == "error" and not self.conflicted_repos:
+            # Only show generic error if not already showing conflicts
+            parts.append("<red>✗ Sync error</red>")
+
+        # Priority 3: Last sync time
+        if self.config.auto_sync_enabled and self.last_sync_time:
+            sync_time_str = format_time_ago(self.last_sync_time)
+            parts.append(f"<green>Synced {sync_time_str}</green>")
+        elif self.config.auto_sync_enabled:
+            parts.append("<dim>Not synced yet</dim>")
+
+        # Priority 4: Last reload time
+        if self.last_reload_time:
+            reload_time_str = format_time_ago(self.last_reload_time)
+            parts.append(f"<blue>Reloaded {reload_time_str}</blue>")
+
+        # Priority 5: Auto-sync status (if enabled)
+        if self.config.auto_sync_enabled:
+            interval_str = format_interval(self.config.auto_sync_interval)
+            parts.append(f"<dim>Auto-sync: ON ({interval_str})</dim>")
+
+        return " | ".join(parts) if parts else ""
+
+    def _get_shortcuts_text(self, terminal_width: int) -> str:
+        """Get keyboard shortcuts based on terminal width.
+
+        Args:
+            terminal_width: Current terminal width in columns
+
+        Returns:
+            HTML-formatted shortcuts string responsive to width
+        """
+        # Very narrow (<80 cols): Just help hint
+        if terminal_width < 80:
+            return "[?]help"
+
+        # Narrow (80-120 cols): Minimal shortcuts
+        if terminal_width < 120:
+            return "[a]dd [e]dit [d]one [s]ync [/]filter [q]uit"
+
+        # Medium (120-160 cols): Standard shortcuts
+        if terminal_width < 160:
+            return (
+                "[a]dd [e]dit [d]one [p]rogress [c]cancelled [v]archive [m]ove [l]delete "
+                "[s]ync [/]filter [r]tree [q]uit"
+            )
+
+        # Wide (>=160 cols): Full shortcuts
+        return (
+            "[a]dd [e]dit [d]one [p]rogress [c]ancelled ar[v]hive [m]ove de[l]ete "
+            "s[u]btask ex[t]end [s]ync [/]filter t[r]ee [q]uit | Multi-select: Space"
         )
-        return HTML(f" {shortcuts} ")
+
+    def _get_status_bar_text(self) -> FormattedText:
+        """Get status bar with sync/reload info and responsive shortcuts.
+
+        Returns a two-line status bar (when terminal is wide enough):
+        - Line 1: Status info (sync/reload times, conflicts, auto-sync status)
+        - Line 2: Keyboard shortcuts (responsive to terminal width)
+
+        For narrow terminals (<120 cols), combines both into single line.
+        """
+        # Get terminal width for responsive layout
+        _, terminal_width = self._get_terminal_size()
+
+        # Build status information (always priority)
+        status_info = self._build_status_info()
+
+        # Get shortcuts based on terminal width
+        shortcuts = self._get_shortcuts_text(terminal_width)
+
+        # Two-line layout for medium/wide terminals (>=120 cols)
+        if terminal_width >= 120 and status_info:
+            return HTML(f" {status_info}\n {shortcuts} ")
+
+        # Single-line layout for narrow terminals
+        # Combine status and minimal shortcuts
+        if status_info:
+            return HTML(f" {status_info} | {shortcuts} ")
+        else:
+            # Fallback to just shortcuts if no status info
+            return HTML(f" {shortcuts} ")
 
     def _get_task_detail_text(self) -> FormattedText:
         """Get formatted details for the currently selected task."""
@@ -583,11 +880,11 @@ class TaskTUI:
         lines = []
 
         # Title header
-        lines.append(f"<b>Task [{display_id_str}]: {task.title}</b>\n\n")
+        lines.append(f"<b>Task [{display_id_str}]: {html.escape(task.title)}</b>\n\n")
 
         # Metadata line 1: Repo, Project, Status, Priority
-        repo = task.repo or "-"
-        project = task.project or "-"
+        repo = html.escape(task.repo) if task.repo else "-"
+        project = html.escape(task.project) if task.project else "-"
 
         # Color-code status
         status_color_map = {
@@ -615,8 +912,8 @@ class TaskTUI:
         lines.append(f"<cyan>Created:</cyan> {created_str} | <cyan>Modified:</cyan> {modified_str}\n")
 
         # Metadata line 3: Assignees, Tags, Due
-        assignees = ", ".join(task.assignees) if task.assignees else "-"
-        tags = ", ".join(task.tags) if task.tags else "-"
+        assignees = ", ".join(html.escape(a) for a in task.assignees) if task.assignees else "-"
+        tags = ", ".join(html.escape(t) for t in task.tags) if task.tags else "-"
         due_str = task.due.strftime("%Y-%m-%d") if task.due else "-"
 
         # Color-code assignees and tags
@@ -630,14 +927,14 @@ class TaskTUI:
         if task.links:
             lines.append("\n<cyan><b>Links:</b></cyan>\n")
             for link in task.links:
-                lines.append(f"  • {link}\n")
+                lines.append(f"  • {html.escape(link)}\n")
 
         # Dependencies section
         deps_info = []
         if task.parent:
-            deps_info.append(f"Parent: {task.parent}")
+            deps_info.append(f"Parent: {html.escape(task.parent)}")
         if task.depends:
-            deps_info.append(f"Depends on: {', '.join(task.depends)}")
+            deps_info.append(f"Depends on: {', '.join(html.escape(d) for d in task.depends)}")
         if deps_info:
             lines.append(f"\n<cyan><b>Dependencies:</b></cyan> {' | '.join(deps_info)}\n")
 
@@ -648,7 +945,7 @@ class TaskTUI:
             desc_lines = task.description.split("\n")
             display_lines = desc_lines[:10]
             for line in display_lines:
-                lines.append(f"{line}\n")
+                lines.append(f"{html.escape(line)}\n")
             if len(desc_lines) > 10:
                 lines.append(f"<dim>... ({len(desc_lines) - 10} more lines)</dim>\n")
 
@@ -716,11 +1013,12 @@ class TaskTUI:
             # Separate top-level and subtasks
             top_level = [t for t in tasks if not t.parent]
             subtasks = [t for t in tasks if t.parent]
-            sorted_top_level = sort_tasks(top_level, self.config)
+            # Pass all tasks for effective due date calculation
+            sorted_top_level = sort_tasks(top_level, self.config, all_tasks=tasks)
             tree_items = build_task_tree(sorted_top_level + subtasks)
             return [item[0] for item in tree_items]
         else:
-            return sort_tasks(tasks, self.config)
+            return sort_tasks(tasks, self.config, all_tasks=tasks)
 
     def _get_task_list_text(self) -> FormattedText:
         """Get formatted task list for viewport display."""
@@ -893,7 +1191,7 @@ class TaskTUI:
 
             # Format countdown with color
             if task.due:
-                countdown_text, countdown_color = get_countdown_text(task.due)
+                countdown_text, countdown_color = get_countdown_text(task.due, task.status)
                 countdown_text = countdown_text[:max_countdown_width]
                 # Map colors to style classes
                 countdown_style_map = {
@@ -1014,14 +1312,18 @@ class TaskTUI:
         """
 
         # Run the application with async support for background tasks
-        async def run_with_auto_reload():
+        async def run_with_background_tasks():
             # Start auto-reload background task
             self.auto_reload_task = asyncio.create_task(self._auto_reload_loop())
 
+            # Start background sync task if enabled
+            if self.config.auto_sync_enabled:
+                self.background_sync_task = asyncio.create_task(self._background_sync_loop())
+
             try:
                 return await self.app.run_async()
             finally:
-                # Cancel the background task when exiting
+                # Cancel background tasks when exiting
                 if self.auto_reload_task:
                     self.auto_reload_task.cancel()
                     try:
@@ -1029,5 +1331,12 @@ class TaskTUI:
                     except asyncio.CancelledError:
                         pass
 
+                if self.background_sync_task:
+                    self.background_sync_task.cancel()
+                    try:
+                        await self.background_sync_task
+                    except asyncio.CancelledError:
+                        pass
+
         # Run the async function
-        return asyncio.run(run_with_auto_reload())
+        return asyncio.run(run_with_background_tasks())
